@@ -26,15 +26,14 @@ void FileSystem::recursiveGlobDirectoriesInto(vector<string> *list, string const
 
 	while(directoryStack.size() > 0)
 	{
-		vector<string> list;
 		string dir = directoryStack.top();
 		directoryStack.pop();
 
-		FileSystem::globDirectoriesInto(&list, dir + "/*");
-		__foreach(d, list)
+		vector<string> dirList;
+		FileSystem::globDirectoriesInto(&dirList, dir + "/*");
+		__foreach(d, dirList)
 			if(!directories.count(*d))
 				directoryStack.push(*d);
-				
 		directories.insert(dir);
 	}
 	
